@@ -37,18 +37,18 @@ import java.util.concurrent.Callable;
 /**
  * A plugin for the <a href="http://pmd.sourceforge.net/">PMD</a> source code analyzer.
  * <p>
- * Declares a <tt>pmd</tt> configuration which needs to be configured with the PMD library to be used.
+ * Declares a <code>pmd</code> configuration which needs to be configured with the PMD library to be used.
  * <p>
  * For each source set that is to be analyzed, a {@link Pmd} task is created and configured to analyze all Java code.
  * <p>
- * All PMD tasks (including user-defined ones) are added to the <tt>check</tt> lifecycle task.
+ * All PMD tasks (including user-defined ones) are added to the <code>check</code> lifecycle task.
  *
  * @see PmdExtension
  * @see Pmd
  */
 public class PmdPlugin extends AbstractCodeQualityPlugin<Pmd> {
 
-    public static final String DEFAULT_PMD_VERSION = "5.6.1";
+    public static final String DEFAULT_PMD_VERSION = "6.8.0";
     private PmdExtension extension;
 
     @Override
@@ -65,7 +65,7 @@ public class PmdPlugin extends AbstractCodeQualityPlugin<Pmd> {
     protected CodeQualityExtension createExtension() {
         extension = project.getExtensions().create("pmd", PmdExtension.class, project);
         extension.setToolVersion(DEFAULT_PMD_VERSION);
-        extension.setRuleSets(new ArrayList<String>(Arrays.asList("java-basic")));
+        extension.setRuleSets(new ArrayList<String>(Arrays.asList("category/java/errorprone.xml")));
         extension.setRuleSetFiles(project.getLayout().files());
         conventionMappingOf(extension).map("targetJdk", new Callable<Object>() {
             @Override
