@@ -17,21 +17,21 @@ package org.gradle.api.internal.changedetection.state;
 
 import com.google.common.annotations.VisibleForTesting;
 import com.google.common.base.Objects;
-import com.google.common.hash.HashCode;
 import org.gradle.api.file.FileTreeElement;
 import org.gradle.api.internal.cache.StringInterner;
-import org.gradle.api.internal.hash.FileHasher;
 import org.gradle.cache.PersistentIndexedCache;
-import org.gradle.internal.nativeintegration.filesystem.FileMetadataSnapshot;
+import org.gradle.cache.PersistentIndexedCacheParameters;
+import org.gradle.internal.file.FileMetadataSnapshot;
+import org.gradle.internal.hash.FileHasher;
+import org.gradle.internal.hash.HashCode;
 import org.gradle.internal.nativeintegration.filesystem.FileSystem;
-import org.gradle.internal.resource.TextResource;
 import org.gradle.internal.serialize.AbstractSerializer;
 import org.gradle.internal.serialize.Decoder;
 import org.gradle.internal.serialize.Encoder;
 import org.gradle.internal.serialize.HashCodeSerializer;
+import org.gradle.internal.serialize.InterningStringSerializer;
 
 import java.io.File;
-import java.io.InputStream;
 
 public class CachingFileHasher implements FileHasher {
     private final PersistentIndexedCache<String, FileInfo> cache;
@@ -40,30 +40,20 @@ public class CachingFileHasher implements FileHasher {
     private final StringInterner stringInterner;
     private final FileTimeStampInspector timestampInspector;
 
-    public CachingFileHasher(FileHasher delegate, TaskHistoryStore store, StringInterner stringInterner, FileTimeStampInspector timestampInspector, String cacheName, FileSystem fileSystem) {
+    public CachingFileHasher(FileHasher delegate, CrossBuildFileHashCache store, StringInterner stringInterner, FileTimeStampInspector timestampInspector, String cacheName, FileSystem fileSystem) {
         this.delegate = delegate;
         this.fileSystem = fileSystem;
-        this.cache = store.createCache(cacheName, String.class, new FileInfoSerializer(), 400000, true);
+        this.cache = store.createCache(
+            PersistentIndexedCacheParameters.of(cacheName, new InterningStringSerializer(stringInterner), new FileInfoSerializer()),
+            400000,
+            true);
         this.stringInterner = stringInterner;
         this.timestampInspector = timestampInspector;
     }
 
-    public static boolean isLog() {
-        return System.getProperty("org.gradle.internal.changes.log", "false").equalsIgnoreCase("true");
-    }
-
     @Override
-    public HashCode hash(TextResource resource) {
-        File file = resource.getFile();
-        if (file != null) {
-            return hash(file);
-        }
-        return delegate.hash(resource);
-    }
-
-    @Override
-    public HashCode hash(InputStream inputStream) {
-        return delegate.hash(inputStream);
+    public String toString() {
+        return "{hasher cache: " + cache + "}";
     }
 
     @Override
