@@ -52,8 +52,8 @@ public class DefaultProjectDependencyPublicationResolver implements ProjectDepen
         // Ensure target project is configured
         projectConfigurer.configureFully(dependencyProject);
 
-        List<ProjectPublication> publications = new ArrayList<ProjectPublication>();
-        for (ProjectPublication publication : publicationRegistry.getPublications(dependencyProject.getPath())) {
+        List<ProjectComponentPublication> publications = new ArrayList<ProjectComponentPublication>();
+        for (ProjectComponentPublication publication : publicationRegistry.getPublications(ProjectComponentPublication.class, dependencyProject.getIdentityPath())) {
             if (!publication.isLegacy() && publication.getCoordinates(coordsType) != null) {
                 publications.add(publication);
             }
@@ -69,15 +69,15 @@ public class DefaultProjectDependencyPublicationResolver implements ProjectDepen
 
         // Select all entry points. An entry point is a publication that does not contain a component whose parent is also published
         Set<SoftwareComponent> ignored = new HashSet<SoftwareComponent>();
-        for (ProjectPublication publication : publications) {
+        for (ProjectComponentPublication publication : publications) {
             if (publication.getComponent() != null && publication.getComponent() instanceof ComponentWithVariants) {
                 ComponentWithVariants parent = (ComponentWithVariants) publication.getComponent();
                 ignored.addAll(parent.getVariants());
             }
         }
-        Set<ProjectPublication> topLevel = new LinkedHashSet<ProjectPublication>();
-        Set<ProjectPublication> topLevelWithComponent = new LinkedHashSet<ProjectPublication>();
-        for (ProjectPublication publication : publications) {
+        Set<ProjectComponentPublication> topLevel = new LinkedHashSet<ProjectComponentPublication>();
+        Set<ProjectComponentPublication> topLevelWithComponent = new LinkedHashSet<ProjectComponentPublication>();
+        for (ProjectComponentPublication publication : publications) {
             if (!publication.isAlias() && (publication.getComponent() == null || !ignored.contains(publication.getComponent()))) {
                 topLevel.add(publication);
                 if (publication.getComponent() != null) {
@@ -91,7 +91,7 @@ public class DefaultProjectDependencyPublicationResolver implements ProjectDepen
         }
 
         // See if all entry points have the same identifier
-        Iterator<ProjectPublication> iterator = topLevel.iterator();
+        Iterator<ProjectComponentPublication> iterator = topLevel.iterator();
         T candidate = iterator.next().getCoordinates(coordsType);
         while (iterator.hasNext()) {
             T alternative = iterator.next().getCoordinates(coordsType);
@@ -100,7 +100,7 @@ public class DefaultProjectDependencyPublicationResolver implements ProjectDepen
                 formatter.node("Publishing is not able to resolve a dependency on a project with multiple publications that have different coordinates.");
                 formatter.node("Found the following publications in " + dependencyProject.getDisplayName());
                 formatter.startChildren();
-                for (ProjectPublication publication : topLevel) {
+                for (ProjectComponentPublication publication : topLevel) {
                     formatter.node(publication.getDisplayName().getCapitalizedDisplayName() + " with coordinates " + publication.getCoordinates(coordsType));
                 }
                 formatter.endChildren();
