@@ -195,17 +195,17 @@ public class IdeaModule {
      * <p>
      * <b>since</b> 1.0-milestone-2
      * <p>
-     * If your project has problems with unique names it is recommended to always run <tt>gradle idea</tt> from the
+     * If your project has problems with unique names it is recommended to always run <code>gradle idea</code> from the
      * root, i.e. for all subprojects.
      * If you run the generation of the IDEA module only for a single subproject then you may have different results
      * because the unique names are calculated based on IDEA modules that are involved in the specific build run.
      * <p>
-     * If you update the module names then make sure you run <tt>gradle idea</tt> from the root, e.g. for all
+     * If you update the module names then make sure you run <code>gradle idea</code> from the root, e.g. for all
      * subprojects, including generation of IDEA project.
      * The reason is that there may be subprojects that depend on the subproject with amended module name.
      * So you want them to be generated as well because the module dependencies need to refer to the amended project
      * name.
-     * Basically, for non-trivial projects it is recommended to always run <tt>gradle idea</tt> from the root.
+     * Basically, for non-trivial projects it is recommended to always run <code>gradle idea</code> from the root.
      * <p>
      * For example see docs for {@link IdeaModule}
      */
@@ -219,10 +219,7 @@ public class IdeaModule {
 
     /**
      * The directories containing the production sources.
-     * <p>
-     * For backward-compatibility it is set of directories containing the production sources from <tt>project.sourceSets.main.allSource</tt>.
-     * <p>
-     * Starting with Gradle 5.0 it is set of directories containing the production sources from <tt>project.sourceSets.main.allJava</tt>.
+     *
      * For example see docs for {@link IdeaModule}
      */
     public Set<File> getSourceDirs() {
@@ -238,12 +235,10 @@ public class IdeaModule {
      * <p>
      * For example see docs for {@link IdeaModule}
      */
-    @Incubating
     public Set<File> getGeneratedSourceDirs() {
         return generatedSourceDirs;
     }
 
-    @Incubating
     public void setGeneratedSourceDirs(Set<File> generatedSourceDirs) {
         this.generatedSourceDirs = generatedSourceDirs;
     }
@@ -318,10 +313,7 @@ public class IdeaModule {
 
     /**
      * The directories containing the test sources.
-     * <p>
-     * For backward-compatibility it is set of directories containing the test sources from <tt>project.sourceSets.test.allSource</tt>.
-     * <p>
-     * Starting with Gradle 5.0 it is set of directories containing the test sources from <tt>project.sourceSets.test.allJava</tt>.
+     *
      * For example see docs for {@link IdeaModule}
      */
     public Set<File> getTestSourceDirs() {
@@ -456,12 +448,10 @@ public class IdeaModule {
      * <p>
      * The Idea module language level is based on the {@code sourceCompatibility} settings for the associated Gradle project.
      */
-    @Incubating
     public IdeaLanguageLevel getLanguageLevel() {
         return languageLevel;
     }
 
-    @Incubating
     public void setLanguageLevel(IdeaLanguageLevel languageLevel) {
         this.languageLevel = languageLevel;
     }
@@ -472,12 +462,10 @@ public class IdeaModule {
      * <p>
      * The Idea module bytecode version is based on the {@code targetCompatibility} settings for the associated Gradle project.
      */
-    @Incubating
     public JavaVersion getTargetBytecodeVersion() {
         return targetBytecodeVersion;
     }
 
-    @Incubating
     public void setTargetBytecodeVersion(JavaVersion targetBytecodeVersion) {
         this.targetBytecodeVersion = targetBytecodeVersion;
     }
@@ -485,12 +473,10 @@ public class IdeaModule {
     /**
      * The Scala version used by this module.
      */
-    @Incubating
     public ScalaPlatform getScalaPlatform() {
         return scalaPlatform;
     }
 
-    @Incubating
     public void setScalaPlatform(ScalaPlatform scalaPlatform) {
         this.scalaPlatform = scalaPlatform;
     }
